#-*- coding: utf-8 -*-
import unittest
from freq import Freq

class TestMethods(unittest.TestCase):

    def test_initialize(self):
        country_codes = ["US", "US", "CA", "US"]
        freqs = Freq(country_codes)
        self.assertEqual(0.75, freqs["US"])
        self.assertEqual(0.25, freqs["CA"])

    def test_nones(self):
        mexican_food = ["Taco", "Chilaquiles", "Mole", "Taco", "Burrito"]
        freqs = Freq(mexican_food)
        self.assertEqual(0, freqs["Bento Box"])



from distutils.core import setup

setup(
  name = 'freq',
  packages = ['freq'],
  package_dir = {'freq': 'freq'},
  package_data = {'freq': ['__init__.py', 'test.py']},
  version = '1.0.1',
  description = 'Frequency Calculator for Python',
  author = 'Daniel J. Dufour',
  author_email = 'daniel.j.dufour@gmail.com',
  url = 'https://github.com/DanielJDufour/freq',
  download_url = 'https://github.com/DanielJDufour/freq/tarball/download',
  keywords = ['counter', 'dict', 'frequency'],
  classifiers = [],
  install_requires=[]
)



from collections import Counter

class Freq(Counter):

    def __init__(self, items):
        length = len(items)
        counts = Counter(items)
        for item, count in counts.items():
            frequency = float(count) / length
            self.__setitem__(item, frequency)
